# -*- coding: utf-8 -*-
# Copyright 2015 grafana-dashboard-builder contributors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from grafana_dashboards.components.base import JsonListGenerator, JsonGenerator
from grafana_dashboards.common import get_component_type
from grafana_dashboards.components.panels import Panels

__author__ = 'Jakub Plichta <jakub.plichta@gmail.com>'


class Rows(JsonListGenerator):
    def __init__(self, data, registry):
        super(Rows, self).__init__(data, registry, RowsItemBase)


class RowsItemBase(JsonGenerator):
    pass


class Row(RowsItemBase):
    def gen_json_from_data(self, data, context):
        row_json = super(Row, self).gen_json_from_data(data, context)
        row_json.update({
            'title': data.get('title', ''),
            'height': data.get('height', '250px'),
            'showTitle': data.get('showTitle', False),
            'collapse': data.get('collapse', False),
            'panels': []
        })
        if get_component_type(Panels) in data:
            row_json['panels'] = self.registry.create_component(Panels, data).gen_json()
        return row_json



# -*- coding: utf-8 -*-
# Copyright 2015 grafana-dashboard-builder contributors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from grafana_dashboards.components.base import JsonListGenerator, JsonGenerator
from grafana_dashboards.common import get_component_type
from grafana_dashboards.components.links import Links

__author__ = 'Jakub Plichta <jakub.plichta@gmail.com>'


class Panels(JsonListGenerator):
    def __init__(self, data, registry):
        super(Panels, self).__init__(data, registry, PanelsItemBase)


class PanelsItemBase(JsonGenerator):
    pass


class Graph(PanelsItemBase):

    # noinspection PySetFunctionToLiteral
    _copy_fields = set(['stack', 'fill', 'aliasColors', 'leftYAxisLabel', 'bars', 'lines', 'y_formats'])

    def gen_json_from_data(self, data, context):
        panel_json = super(Graph, self).gen_json_from_data(data, context)
        panel_json.update({
            'type': 'graph',
            'title': self.data.get('title', None),
            'span': self.data.get('span', None),
        })
        targets = self.data.get('targets', [])
        if 'target' in self.data:
            targets.append(self.data['target'])
        panel_json['targets'] = map(lambda v: {'target': v}, targets)
        panel_json['nullPointMode'] = self.data.get('nullPointMode', 'null')
        if 'grid' in self.data:
            panel_json['grid'] = {
                'leftMax': self.data['grid'].get('leftMax', None),
                'rightMax': self.data['grid'].get('rightMax', None),
                'leftMin': self.data['grid'].get('leftMin', None),
                'rightMin': self.data['grid'].get('rightMin', None)
            }
        if 'legend' in self.data:
            panel_json['legend'] = {
                'show': self.data['legend'].get('show', True),
                'values': self.data['legend'].get('values', False),
                'min': self.data['legend'].get('min', False),
                'max': self.data['legend'].get('max', False),
                'current': self.data['legend'].get('current', False),
                'total': self.data['legend'].get('total', False),
                'avg': self.data['legend'].get('avg', False),
                'alignAsTable': self.data['legend'].get('alignAsTable', False),
                'hideEmpty': self.data['legend'].get('hideEmpty', False)
            }
        if 'tooltip' in self.data:
            panel_json['tooltip'] = {
                'value_type': self.data['tooltip'].get('value_type', 'individual'),
                'shared': self.data['tooltip'].get('shared', False),
            }
        if get_component_type(Links) in self.data:
            panel_json['links'] = self.registry.create_component(Links, self.data).gen_json()
        return panel_json


class SingleStat(PanelsItemBase):

    # noinspection PySetFunctionToLiteral
    _copy_fields = set(['prefix', 'postfix', 'nullText', 'format'])

    def gen_json_from_data(self, data, context):
        panel_json = super(SingleStat, self).gen_json_from_data(data, context)
        panel_json.update({
            'type': 'singlestat',
            'title': data.get('title', None),
            'span': data.get('span', None),
            'targets': map(lambda v: {'target': v}, data.get('targets', [])),
            'nullPointMode': data.get('nullPointMode', 'null'),
            'valueName': data.get('valueName', 'current')
        })
        if 'sparkline' in data:
            panel_json['sparkline'] = {
                'show': True,
                'full': data['sparkline'].get('full', False),
                'lineColor': data['sparkline'].get('lineColor', 'rgb(31, 120, 193)'),
                'fillColor': data['sparkline'].get('fillColor', 'rgba(31, 118, 189, 0.18)')
            }
        if 'valueMaps' in data:
            panel_json['valueMaps'] = [{'value': value, 'op': '=', 'text': text} for value, text in
                                       data['valueMaps'].iteritems()]
        if get_component_type(Links) in data:
            panel_json['links'] = self.registry.create_component(Links, data).gen_json()
        return panel_json


class Text(PanelsItemBase):
    def gen_json_from_data(self, data, context):
        panel_json = super(Text, self).gen_json_from_data(data, context)
        panel_json.update({
            'type': 'text',
            'title': data.get('title', None),
            'span': data.get('span', None),
            'mode': data.get('mode', 'text'),
            'content': data.get('content', '')
        })
        return panel_json



# -*- coding: utf-8 -*-
# Copyright 2015 grafana-dashboard-builder contributors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import logging
import string

from grafana_dashboards import errors
from grafana_dashboards.common import get_component_type
from grafana_dashboards.context import Context

__author__ = 'Jakub Plichta <jakub.plichta@gmail.com>'


logger = logging.getLogger(__name__)


def get_generators():
    return _get_subclasses(JsonGenerator)


def _get_subclasses(clazz):
    """

    :type clazz: type
    """
    direct_subclasses = clazz.__subclasses__()
    return [sub for sub in
            direct_subclasses + [sub_class for direct in direct_subclasses for sub_class in _get_subclasses(direct)]
            if sub not in (ComponentBase, JsonGenerator, JsonListGenerator)]


def get_placeholders(component_name):
    return [v[1] for v in string.Formatter().parse(component_name) if v[1]]


class ComponentRegistry(object):
    def __init__(self):
        super(ComponentRegistry, self).__init__()
        self._types = {}
        self._components = {}
        for clazz in _get_subclasses(ComponentBase):
            logger.info('Loading component type %s', clazz)
            self._types[get_component_type(clazz)] = clazz
            self._components[clazz] = {}

    def _class_for_type(self, component_type):
        if isinstance(component_type, str):
            component_type = self._types.get(component_type)
        if self._components.get(component_type) is None:
            raise errors.UnregisteredComponentError("No component of type '%s' found!" % component_type)
        return component_type

    def add(self, component):
        """

        :type component: dict
        """
        if len(component) > 2:
            raise errors.WrongComponentAttributeCountError(
                'Component must have exactly 2 attributes - name and component type with data.'
                'This contains %s attributes' % len(component.keys()))
        component_name = component.get('name')
        if component_name is None:
            logger.info("Component '%s' does not have 'name' attribute, skipping", component.keys())
            return
        component_type = None
        for key in component.keys():
            if key == 'name':
                continue
            component_type = key
            break
        try:
            clazz = self._class_for_type(component_type)
        except errors.UnregisteredComponentError:
            logger.info("Missing implementation class for component '%s', skipping", component_type)
            return
        logger.debug("Adding component '%s' with name '%s'", component_type, component_name)
        components = self._get_component(clazz)
        if component_name in components:
            raise errors.DuplicateKeyError(
                "Key '%s' is already defined for component %s" % (component_name, component_type))
        components[component_name] = self.create_component(clazz, component)

    def __getitem__(self, item):
        return self._get_component(item).values()

    def _get_component(self, item):
        component = self._components.get(item)
        if component is None:
            raise errors.UnregisteredComponentError("No component of type '%s' found!" % item)
        return component

    def create_component(self, component_type, data):
        return self._class_for_type(component_type)(data, self)

    def get_component(self, component_type, name):
        component = self._get_component(component_type).get(name)
        if component is None:
            raise errors.UnregisteredComponentError("No component '%s' with name '%s' found!" % (component_type, name))
        return component


class ComponentBase(object):
    def __init__(self, data, registry):
        """

        :type registry: ComponentRegistry
        """
        super(ComponentBase, self).__init__()
        self.data = data[get_component_type(type(self))]
        if self.data is None:
            self.data = {}
        self.name = data.get('name')
        self.registry = registry


class JsonGenerator(ComponentBase):

    _copy_fields = set()

    def gen_json(self, context=Context()):
        return self.gen_json_from_data(context.expand_placeholders(self.data), context)

    def gen_json_from_data(self, data, context):
        component_type = get_component_type(type(self))
        if self.name:
            logger.debug("Processing component '%s' with name '%s' from template '%s'",
                         component_type, context.expand_placeholders(self.name), self.name)
        else:
            logger.debug("Processing anonymous component '%s'", component_type)
        json = {}
        for field in self._copy_fields:
            if field in data:
                json[field] = data[field]
        return json


class JsonListGenerator(JsonGenerator):
    def __init__(self, data, registry, item_base_class):
        super(JsonListGenerator, self).__init__(data, registry)
        self.component_item_types = [get_component_type(clazz) for clazz in _get_subclasses(item_base_class)]

    def gen_json_from_data(self, data, context):
        super(JsonListGenerator, self).gen_json_from_data(data, context)
        result_list = []
        for items in data:
            if isinstance(items, str):
                # this is component without context
                result_list += self.registry.get_component(type(self), items).gen_json()
            else:
                # TODO add check for dictionary
                for (item_type, item_data) in items.iteritems():
                    if item_type not in self.component_item_types:
                        # this is named component with context
                        for context in Context.create_context(item_data, get_placeholders(item_type)):
                            result_list += self.registry.get_component(type(self), item_type).gen_json(context)
                    else:
                        # this is inplace defined component
                        item = self.registry.create_component(item_type, {item_type: item_data}).gen_json()
                        if isinstance(item, list):
                            result_list += item
                        else:
                            result_list.append(item)
        return result_list



# -*- coding: utf-8 -*-
# Copyright 2015 grafana-dashboard-builder contributors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json
import logging
import os
import errno

__author__ = 'Jakub Plichta <jakub.plichta@gmail.com>'


logger = logging.getLogger(__name__)


class DashboardExporter(object):

    def process_dashboard(self, project_name, dashboard_name, dashboard_data):
        pass


class ProjectProcessor(object):

    def __init__(self, dashboard_processors):
        """

        :type dashboard_processors: list[grafana_dashboards.builder.DashboardExporter]
        """
        super(ProjectProcessor, self).__init__()
        self._dashboard_processors = dashboard_processors

    def process_projects(self, projects, parent_context=None):
        """

        :type projects: list[grafana_dashboards.components.projects.Project]
        :type parent_context: dict
        """
        for project in projects:
            logger.info("Processing project '%s'", project.name)
            for context in project.get_contexts(parent_context):
                for dashboard in project.get_dashboards():
                    json_obj = dashboard.gen_json(context)
                    dashboard_name = context.expand_placeholders(dashboard.name)
                    for processor in self._dashboard_processors:
                        processor.process_dashboard(project.name, dashboard_name, json_obj)


class FileExporter(DashboardExporter):

    def __init__(self, output_folder):
        super(DashboardExporter, self).__init__()
        self._output_folder = output_folder
        if not os.path.exists(self._output_folder):
            os.makedirs(self._output_folder)
        if not os.path.isdir(self._output_folder):
            raise Exception("'{0}' must be a directory".format(self._output_folder))

    def process_dashboard(self, project_name, dashboard_name, dashboard_data):
        super(FileExporter, self).process_dashboard(project_name, dashboard_name, dashboard_data)
        dirname = os.path.join(self._output_folder, project_name)
        try:
            os.makedirs(dirname)
        except OSError as e:
            if e.errno != errno.EEXIST:
                raise

        dashboard_path = os.path.join(dirname, dashboard_name + '.json')
        logger.info("Saving dashboard '%s' to '%s'", dashboard_name, os.path.abspath(dashboard_path))
        with file(dashboard_path, 'w') as f:
            json.dump(dashboard_data, f, sort_keys=True, indent=2, separators=(',', ': '))



# -*- coding: utf-8 -*-
# Copyright 2015 grafana-dashboard-builder contributors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import base64
import cookielib
import json
import logging
import urllib2
from urlparse import urlparse

__author__ = 'Jakub Plichta <jakub.plichta@gmail.com>'

logger = logging.getLogger(__name__)


class Connection(object):
    _headers = {
        'Content-type': 'application/json',
        'Accept': 'application/json'
    }

    def __init__(self, username, password, host, debug=0):
        logger.debug('Creating new connection with username=%s host=%s', username, host)
        self._host = host

        base64string = base64.encodestring('%s:%s' % (username, password)).replace('\n', '')
        self._headers['Authorization'] = 'Basic %s' % base64string

        self._opener = urllib2.build_opener(urllib2.HTTPHandler(debuglevel=debug),
                                            urllib2.HTTPSHandler(debuglevel=debug),
                                            urllib2.HTTPCookieProcessor(cookielib.CookieJar()),
                                            LoggingHandler(),
                                            urllib2.HTTPDefaultErrorHandler())

    def make_request(self, uri, body=None):
        request = urllib2.Request('{0}{1}'.format(self._host, uri),
                                  json.dumps(body) if body else None,
                                  headers=self._headers)
        response_body = self._opener.open(request).read()
        return {} if (response_body is None or response_body == '') else json.loads(response_body)


class LoggingHandler(urllib2.BaseHandler):
    def __init__(self):
        pass

    # noinspection PyMethodMayBeStatic
    def http_request(self, request):
        path = urlparse(request.get_full_url()).path
        logger.debug('Sending request: method=%s uri=%s', request.get_method(), path)
        return request

    # noinspection PyMethodMayBeStatic,PyUnusedLocal
    def http_response(self, request, response):
        logger.debug('Response received: status=%s msg=%s', response.getcode(), response.msg)
        return response

    https_request = http_request
    https_response = http_response



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2015 grafana-dashboard-builder contributors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import argparse
import imp
import logging
import os

import yaml

from grafana_dashboards.exporter import ProjectProcessor, FileExporter
from grafana_dashboards.client.elastic_search import ElasticSearchExporter
from grafana_dashboards.common import get_component_type
from grafana_dashboards.config import Config
from grafana_dashboards.parser import DefinitionParser

__author__ = 'Jakub Plichta <jakub.plichta@gmail.com>'


def _initialize_exporters(exporter_names, exporter_types, config):
    exporters = dict([(get_component_type(exporter), exporter) for exporter in exporter_types])
    exporters = dict([(name[:-9], exporter) for name, exporter in exporters.iteritems() if name[:-9] in exporter_names])
    return [exporter(**config.get_config(name)) for (name, exporter) in exporters.iteritems()]


def _process_paths(paths):
    definition_files = set()
    for paths in paths:
        if os.path.isdir(paths):
            for root, dirs, filenames in os.walk(paths):
                s = set([os.path.join(root, filename) for filename in filenames])
                definition_files = definition_files.union(s)
        else:
            definition_files.add(paths)
    return definition_files


def main():
    logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s', level=logging.DEBUG)
    parser = argparse.ArgumentParser()
    parser.add_argument('-p', '--path', required=True, nargs='+', type=str,
                        help='List of path to YAML definition files')
    parser.add_argument('--project',
                        help='(deprecated, use path) Location of the file containing project definition.')
    parser.add_argument('-o', '--out',
                        help='(deprecated, use config file and file exporter) Path to output folder')
    parser.add_argument('-c', '--config', default='./.grafana/grafana_dashboards.yaml',
                        help='Configuration file containing fine-tuned setup of builder\'s components.')
    parser.add_argument('--context', default='{}',
                        help='YAML structure defining parameters for dashboard definition.'
                             ' Effectively overrides any parameter defined on project level.')
    parser.add_argument('--plugins', nargs='+', type=str,
                        help='List of external component plugins to load')
    parser.add_argument('--exporter', nargs='+', type=str, default=set(), dest='exporters',
                        help='List of dashboard exporters')

    args = parser.parse_args()

    if args.plugins:
        for plugin in args.plugins:
            try:
                imp.load_source('grafana_dashboards.components.$loaded', plugin)
            except Exception as e:
                print 'Cannot load plugin %s: %s' % (plugin, str(e))

    if args.project:
        logging.warn("Using deprecated option '--project'")
        args.path.add(args.project)
    paths = _process_paths(args.path)

    config = Config(args.config)
    exporters = set(args.exporters)
    if args.out:
        logging.warn("Using deprecated option '-o/--out'")
        exporters.add('file')
        config.get_config('file').update(output_folder=args.out)

    dashboard_exporters = _initialize_exporters(exporters, [FileExporter, ElasticSearchExporter], config)

    context = config.get_config('context')
    context.update(yaml.load(args.context))

    projects = DefinitionParser().load_projects(paths)
    project_processor = ProjectProcessor(dashboard_exporters)
    project_processor.process_projects(projects, context)


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
# Copyright 2015 grafana-dashboard-builder contributors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import string
import itertools

__author__ = 'Jakub Plichta <jakub.plichta@gmail.com>'


class Context(object):

    def __init__(self, context=None):
        super(Context, self).__init__()
        if not context:
            context = {}
        self._context = DictDefaultingToPlaceholder(context)

    def expand_placeholders(self, to_expand):
        """

        :rtype : dict
        """
        if isinstance(to_expand, str):
            formatter = string.Formatter()
            (result, to_expand) = (formatter.vformat(to_expand, (), self._context), to_expand)
            while result != to_expand:
                (result, to_expand) = (formatter.vformat(result, (), self._context), result)
            return result
        elif isinstance(to_expand, list):
            return [self.expand_placeholders(value) for value in to_expand]
        elif isinstance(to_expand, dict):
            return dict([(key, self.expand_placeholders(value)) for (key, value) in to_expand.iteritems()])
        else:
            return to_expand

    def __str__(self):
        return str(self._context)

    @staticmethod
    def create_context(data, keys_to_expand=None):
        return (Context(Context(context).expand_placeholders(context))
                for context in ContextExpander(keys_to_expand).create_context(None, data))


class DictDefaultingToPlaceholder(dict):
    def __missing__(self, key):
        return '{' + key + '}'


class ContextExpander(object):
    def __init__(self, keys_to_expand=None):
        super(ContextExpander, self).__init__()
        self._keys_to_expand = keys_to_expand if keys_to_expand else []

    def create_context(self, key, value, parent=None):
        contexts = []
        if isinstance(value, list):
            if key in self._keys_to_expand:
                contexts.append((context for data in value for context in self.create_context(key, data, key)))
        elif isinstance(value, dict):
            for (sub_key, sub_value) in value.iteritems():
                if parent and len(value) == 1:
                    contexts.append(self.create_context(parent, sub_key))
                contexts.append(self.create_context(sub_key, sub_value))
        else:
            contexts.append(itertools.repeat({key: value}, 1))
        for context in itertools.product(*contexts):
            result = {}
            multi = {}
            for context_part in context:
                if len(context_part) == 1:
                    result.update(context_part)
                else:
                    multi.update(context_part)
            result.update(multi)
            yield result



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright 2015 grafana-dashboard-builder contributors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import sys

from setuptools import setup
from setuptools.command.test import test as TestCommand

__author__ = 'Jakub Plichta <jakub.plichta@gmail.com>'


class Tox(TestCommand):
    user_options = [('tox-args=', 'a', "Arguments to pass to tox")]

    def initialize_options(self):
        TestCommand.initialize_options(self)
        self.tox_args = None

    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        # import here, cause outside the eggs aren't loaded
        import tox
        import shlex

        args = self.tox_args
        if args:
            args = shlex.split(self.tox_args)
        errno = tox.cmdline(args=args)
        sys.exit(errno)


params = {
    'name': 'grafana-dashboard-builder',
    'version': '0.1.0a8',
    'packages': [
        'grafana_dashboards',
        'grafana_dashboards.client',
        'grafana_dashboards.components'
    ],
    'scripts': [
        'bin/grafana_dashboard_builder.py'
    ],
    'url': 'https://github.com/jakubplichta/grafana-dashboard-builder',
    'license': 'Apache License, Version 2.0',
    'author': 'Jakub Plichta',
    'author_email': 'jakub.plichta@gmail.com',
    'description': 'Generate Grafana dashboards with YAML',
    'classifiers': [
        'Topic :: Utilities',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
    ],
    'keywords': 'grafana yaml',
    'cmdclass': {'test': Tox},
    'tests_require': ['tox', 'mock'],
    'install_requires': ['PyYAML', 'argparse'],
    'long_description':
        """grafana-dashboard-builder is an open-source tool for easier creation of Grafana dashboards.
It is written in Python and uses YAML descriptors for dashboard
templates.

This project has been inspired by Jenkins Job Builder that
allows users to describe Jenkins jobs with human-readable format. grafana-dashboard-builder
aims to provide similar simplicity to Grafana dashboard creation and to give users easy way how they can create
dashboard templates filled with different configuration."""
}

setup(**params)
